<?php

namespace Drupal\vimeo_embed_field\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\AlertCommand;
use Drupal\Core\Ajax\ChangedCommand;
use Drupal\Core\Ajax\CssCommand;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Ajax\InvokeCommand;
/**
 * Plugin implementation of the 'vimeo' widget.
 *
 * @FieldWidget(
 *   id = "vimeo",
 *   label = @Translation("Vimeo field widget"),
 *   field_types = {
 *     "vimeo"
 *   }
 * )
 */
class VimeoFieldWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return array(
      'size' => 60,
      'placeholder' => '',
    ) + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements = [];

    $elements['size'] = array(
      '#type' => 'number',
      '#title' => t('Size of textfield'),
      '#default_value' => $this->getSetting('size'),
      '#required' => TRUE,
      '#min' => 1,
    );
    $elements['placeholder'] = array(
      '#type' => 'textfield',
      '#title' => t('Placeholder'),
      '#default_value' => $this->getSetting('placeholder'),
      '#description' => t('Text that will be shown inside the field until a value is entered. This hint is usually a sample value or a brief description of the expected format.'),
    );

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];

    $summary[] = t('Textfield size: @size', array('@size' => $this->getSetting('size')));
    if (!empty($this->getSetting('placeholder'))) {
      $summary[] = t('Placeholder: @placeholder', array('@placeholder' => $this->getSetting('placeholder')));
    }

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {  
    
    $item =& $items[$delta];
    
    $element += array(
      '#type' => 'fieldset',
    );
    $element['vimeo_url'] =  array(
      '#type' => 'textfield',
      '#title' => t('Vimeo Video URL'),
      '#default_value' => isset($items[$delta]->vimeo_url) ? $items[$delta]->vimeo_url : NULL,
      '#size' => $this->getSetting('size'),
      '#placeholder' => $this->getSetting('placeholder'),
      '#maxlength' => '255',
      '#description' => t('Enter vimeo video URL here'), 
      '#element_validate' => [[$this, 'validatevimeourl']] 
    );  

    return $element;
  } 

 /**
 *  
 *
 * @param string $vimeo_url
 *   The input submitted to the field.
 *
 * @return string|bool
 *   Returns the vimeo url TRUE or Error.
 */
  public function validatevimeourl(&$element, FormStateInterface $form_state, $form) {
    $vimeo_url = $element['#value'];  
    $id = _get_vimeo_id_from_vimeo_url($vimeo_url);
    if (($id['status'] == 1) && (!empty($id) && (!empty($vimeo_url)) )) {  
      return TRUE;
     } elseif (!empty($vimeo_url)){
      $form_state->setError($element, t('Enter valid vimeo video URL'));
    }

  }


}
